@@ -33,6 +33,7 @@ sub new {
 sub size  { return $_[0]->{length}       };
 sub name  { return $_[0]->{filename}     };
 sub group { return $_[0]->{group}        };
+sub url   { return $_[0]->{url_download} };
 
 sub download {
 
@@ -44,13 +45,22 @@ sub download {
 
     my $res = $self->{agent}->get(@a)
         or croak "LWP internal error: $@";
-    croak "Error saving file to disk"
-        if (defined $args{out} && ! -e $args{out});
 
     die Bio::CIPRES::Error->new( $res->content )
         if (! $res->is_success);
 
-    return $res->decoded_content;
+    if (defined $args{out}) {
+        croak "Error saving file to disk"
+            if (! -e $args{out});
+        croak "Downloaded file wrong size"
+            if (-s $args{out} != $self->size);
+    }
+    else {
+        croak "Downloaded content wrong size"
+            if (length($res->content) != $self->size);
+    }
+
+    return $res->content;
 
 }
 
@@ -85,7 +95,7 @@ Bio::CIPRES::Output - a single CIPRES job output file
 
 =head1 SYNOPSIS
 
-    for my $output ($job->list_outputs) {
+    for my $output ($job->outputs) {
 
         print "filename:", $output->name, "\n";
         print "BIG FILE!!\n" if ($output->size > 1024**3);
@@ -130,9 +140,15 @@ Returns the size of the output file in bytes.
 
 Returns the output group that the file is a member of.
 
+=item B<url>
+
+    my $url = $output->url;
+
+Returns the download URL for the output file
+
 =item B<download>
 
-    my $content = $output->download
+    my $content = $output->download;
     my $res = $output->download( 'out' => $filename );
 
 Attempts to download the output file, and either returns the contents (if no
